==> DateTime-Locale-1.16.tar.gz: DateTime-Locale-1.16/share/nd-ZW.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM"
  ],
  available_formats => {
    E => "ccc",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' y"
  },
  code => "nd-ZW",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Mvu",
    "Sib",
    "Sit",
    "Sin",
    "Sih",
    "Mgq",
    "Son"
  ],
  day_format_narrow => [
    "M",
    "S",
    "S",
    "S",
    "S",
    "M",
    "S"
  ],
  day_format_wide => [
    "Mvulo",
    "Sibili",
    "Sithathu",
    "Sine",
    "Sihlanu",
    "Mgqibelo",
    "Sonto"
  ],
  day_stand_alone_abbreviated => [
    "Mvu",
    "Sib",
    "Sit",
    "Sin",
    "Sih",
    "Mgq",
    "Son"
  ],
  day_stand_alone_narrow => [
    "M",
    "S",
    "S",
    "S",
    "S",
    "M",
    "S"
  ],
  day_stand_alone_wide => [
    "Mvulo",
    "Sibili",
    "Sithathu",
    "Sine",
    "Sihlanu",
    "Mgqibelo",
    "Sonto"
  ],
  era_abbreviated => [
    "BC",
    "AD"
  ],
  era_narrow => [
    "BC",
    "AD"
  ],
  era_wide => [
    "UKristo angakabuyi",
    "Ukristo ebuyile"
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "North Ndebele",
  month_format_abbreviated => [
    "Zib",
    "Nhlo",
    "Mbi",
    "Mab",
    "Nkw",
    "Nhla",
    "Ntu",
    "Ncw",
    "Mpan",
    "Mfu",
    "Lwe",
    "Mpal"
  ],
  month_format_narrow => [
    "Z",
    "N",
    "M",
    "M",
    "N",
    "N",
    "N",
    "N",
    "M",
    "M",
    "L",
    "M"
  ],
  month_format_wide => [
    "Zibandlela",
    "Nhlolanja",
    "Mbimbitho",
    "Mabasa",
    "Nkwenkwezi",
    "Nhlangula",
    "Ntulikazi",
    "Ncwabakazi",
    "Mpandula",
    "Mfumfu",
    "Lwezi",
    "Mpalakazi"
  ],
  month_stand_alone_abbreviated => [
    "Zib",
    "Nhlo",
    "Mbi",
    "Mab",
    "Nkw",
    "Nhla",
    "Ntu",
    "Ncw",
    "Mpan",
    "Mfu",
    "Lwe",
    "Mpal"
  ],
  month_stand_alone_narrow => [
    "Z",
    "N",
    "M",
    "M",
    "N",
    "N",
    "N",
    "N",
    "M",
    "M",
    "L",
    "M"
  ],
  month_stand_alone_wide => [
    "Zibandlela",
    "Nhlolanja",
    "Mbimbitho",
    "Mabasa",
    "Nkwenkwezi",
    "Nhlangula",
    "Ntulikazi",
    "Ncwabakazi",
    "Mpandula",
    "Mfumfu",
    "Lwezi",
    "Mpalakazi"
  ],
  name => "North Ndebele Zimbabwe",
  native_language => "isiNdebele",
  native_name => "isiNdebele Zimbabwe",
  native_script => undef,
  native_territory => "Zimbabwe",
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "Kota 1",
    "Kota 2",
    "Kota 3",
    "Kota 4"
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "Kota 1",
    "Kota 2",
    "Kota 3",
    "Kota 4"
  ],
  script => undef,
  territory => "Zimbabwe",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 31
}

==> DateTime-Locale-1.28.tar.gz: DateTime-Locale-1.28/share/nd-ZW.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "nd-ZW",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Mvu",
    "Sib",
    "Sit",
    "Sin",
    "Sih",
    "Mgq",
    "Son",
  ],
  day_format_narrow => [
    "M",
    "S",
    "S",
    "S",
    "S",
    "M",
    "S",
  ],
  day_format_wide => [
    "Mvulo",
    "Sibili",
    "Sithathu",
    "Sine",
    "Sihlanu",
    "Mgqibelo",
    "Sonto",
  ],
  day_stand_alone_abbreviated => [
    "Mvu",
    "Sib",
    "Sit",
    "Sin",
    "Sih",
    "Mgq",
    "Son",
  ],
  day_stand_alone_narrow => [
    "M",
    "S",
    "S",
    "S",
    "S",
    "M",
    "S",
  ],
  day_stand_alone_wide => [
    "Mvulo",
    "Sibili",
    "Sithathu",
    "Sine",
    "Sihlanu",
    "Mgqibelo",
    "Sonto",
  ],
  era_abbreviated => [
    "BC",
    "AD",
  ],
  era_narrow => [
    "BC",
    "AD",
  ],
  era_wide => [
    "UKristo angakabuyi",
    "Ukristo ebuyile",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "North Ndebele",
  month_format_abbreviated => [
    "Zib",
    "Nhlo",
    "Mbi",
    "Mab",
    "Nkw",
    "Nhla",
    "Ntu",
    "Ncw",
    "Mpan",
    "Mfu",
    "Lwe",
    "Mpal",
  ],
  month_format_narrow => [
    "Z",
    "N",
    "M",
    "M",
    "N",
    "N",
    "N",
    "N",
    "M",
    "M",
    "L",
    "M",
  ],
  month_format_wide => [
    "Zibandlela",
    "Nhlolanja",
    "Mbimbitho",
    "Mabasa",
    "Nkwenkwezi",
    "Nhlangula",
    "Ntulikazi",
    "Ncwabakazi",
    "Mpandula",
    "Mfumfu",
    "Lwezi",
    "Mpalakazi",
  ],
  month_stand_alone_abbreviated => [
    "Zib",
    "Nhlo",
    "Mbi",
    "Mab",
    "Nkw",
    "Nhla",
    "Ntu",
    "Ncw",
    "Mpan",
    "Mfu",
    "Lwe",
    "Mpal",
  ],
  month_stand_alone_narrow => [
    "Z",
    "N",
    "M",
    "M",
    "N",
    "N",
    "N",
    "N",
    "M",
    "M",
    "L",
    "M",
  ],
  month_stand_alone_wide => [
    "Zibandlela",
    "Nhlolanja",
    "Mbimbitho",
    "Mabasa",
    "Nkwenkwezi",
    "Nhlangula",
    "Ntulikazi",
    "Ncwabakazi",
    "Mpandula",
    "Mfumfu",
    "Lwezi",
    "Mpalakazi",
  ],
  name => "North Ndebele Zimbabwe",
  native_language => "isiNdebele",
  native_name => "isiNdebele Zimbabwe",
  native_script => undef,
  native_territory => "Zimbabwe",
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Kota 1",
    "Kota 2",
    "Kota 3",
    "Kota 4",
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Kota 1",
    "Kota 2",
    "Kota 3",
    "Kota 4",
  ],
  script => undef,
  territory => "Zimbabwe",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 37,
}
